# Wasot Use-Cases

Wasot allows for collaboration between me and and tools to outsource work out
of my head, so that I can work at the speed of thought. See the [design principles](./principles.md) for more background.

These use-cases are planned as soon as I get there:

- Zettelkasten note taking in neovim
- Text-based jupyter notebook replacement
- Margin-Notes with flashcards
- Flashcard format
- Drawings via plantuml and Mermaid
- Bigger writing projects
- Essays to organize my thoughts
- ... Somewhere in this repository is another list

All of my writing should be done in wasot.

## Zettelkasten note taking in neovim

Write wasot documents and [link](./links.md) them together.
Links are supported by default! So here is nothing more to do.
Each document and block can have a unique [ID](./document_ids.md).

```wasot
.# Zettelkasten Entry title

.idea
The documents still have blocks with meta-data.
But there can be ((links) :123-a-unique-id) where the 
target is either a document-id or a block-id. 
```

## Text-based jupyter notebook replacement

## Margin-Notes with flashcards

## Flashcard format

## Drawings via plantuml and Mermaid

## Bigger writing projects

## Essays to organize my thoughts
